@@ -6,6 +6,10 @@ class RecVolumes
   private:
     File *SrcFile[256];
     Array<byte> Buf;
+
+#ifdef RAR_SMP
+    ThreadPool RSThreadPool;
+#endif
   public:
     RecVolumes();
     ~RecVolumes();
@@ -13,4 +17,4 @@ class RecVolumes
     bool Restore(RAROptions *Cmd,const char *Name,const wchar *NameW,bool Silent);
 };
 
-#endif
\ No newline at end of file
+#endif
